@@ -30,16 +30,20 @@
 #include "baobab-remote-connect-dialog.h"
 
 #include <string.h>
-
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-volume.h>
 #include <glib/gi18n.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
 
 #include "baobab.h"
 
+
+/* Translators: all the strings in this file are meant to map the
+   similar strings inside nautilus-connect-server and should be 
+   translated the same way
+*/
+
 struct _BaobabRemoteConnectDialogDetails {
-	
+
 	GtkWidget *table;
 	
 	GtkWidget *type_combo;
@@ -50,33 +54,145 @@ struct _BaobabRemoteConnectDialogDetails {
 	GtkWidget *folder_entry;
 	GtkWidget *domain_entry;
 	GtkWidget *user_entry;
-
-	GtkWidget *name_entry;
 };
 
 static void  baobab_remote_connect_dialog_class_init       (BaobabRemoteConnectDialogClass *class);
 static void  baobab_remote_connect_dialog_init             (BaobabRemoteConnectDialog      *dialog);
 
-#define RESPONSE_CONNECT GTK_RESPONSE_OK
-/*
-enum {
-	
-	RESPONSE_CONNECT
-};	
-*/
+G_DEFINE_TYPE(BaobabRemoteConnectDialog, baobab_remote_connect_dialog, GTK_TYPE_DIALOG)
 
-/* Keep this order in sync with strings below */
-enum {
-	TYPE_SSH,
-	TYPE_ANON_FTP,
-	TYPE_FTP,
-	TYPE_SMB,
-	TYPE_DAV,
-	TYPE_DAVS,
-	TYPE_URI
+#define RESPONSE_CONNECT GTK_RESPONSE_OK
+
+
+static void
+display_error_dialog (GError *error, 
+		      GFile *location,
+		      GtkWindow *parent)
+{
+	GtkWidget *dlg;
+	char *parse_name;
+	char *error_message;
+
+	parse_name = g_file_get_parse_name (location);
+	error_message = g_strdup_printf (_("Cannot scan location \"%s\""),
+					 parse_name);
+	g_free (parse_name);
+
+	dlg = gtk_message_dialog_new (parent,
+				      GTK_DIALOG_DESTROY_WITH_PARENT,
+				      GTK_MESSAGE_ERROR,
+				      GTK_BUTTONS_OK,
+				      error_message, NULL);
+
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
+						  "%s", error->message);
+
+	g_free (error_message);
+
+	gtk_dialog_run (GTK_DIALOG (dlg));
+	gtk_widget_destroy (dlg);
+}
+
+static void
+mount_enclosing_ready_cb (GFile *location,
+			  GAsyncResult *res,
+			  GtkWindow *app)
+{
+	gboolean success;
+	GError *error = NULL;
+
+	success = g_file_mount_enclosing_volume_finish (location,
+							res, &error);
+
+	if (success ||
+	    g_error_matches (error, G_IO_ERROR, G_IO_ERROR_ALREADY_MOUNTED)) {
+		baobab_scan_location (location);
+	}
+	else {
+		display_error_dialog (error, location, app);
+	}
+
+	if (error)
+		g_error_free (error);
+
+	if (location)
+		g_object_unref (location);
+}
+
+static void
+connect_server_dialog_present_uri (GtkWindow *app,
+				   GFile *location,
+				   GtkWidget *widget)
+{
+	GMountOperation *op;
+
+	op = gtk_mount_operation_new (GTK_WINDOW (widget));
+
+	g_file_mount_enclosing_volume (location,
+				       0, op,
+				       NULL,
+				       (GAsyncReadyCallback) mount_enclosing_ready_cb,
+				       app);
+	g_object_unref (op);
+}
+
+struct MethodInfo {
+	const char *scheme;
+	guint flags;
 };
 
-G_DEFINE_TYPE(BaobabRemoteConnectDialog, baobab_remote_connect_dialog, GTK_TYPE_DIALOG)
+/* A collection of flags for MethodInfo.flags */
+enum {
+	DEFAULT_METHOD = 0x00000001,
+	
+	/* Widgets to display in setup_for_type */
+	SHOW_SHARE     = 0x00000010,
+	SHOW_PORT      = 0x00000020,
+	SHOW_USER      = 0x00000040,
+	SHOW_DOMAIN    = 0x00000080,
+	
+	IS_ANONYMOUS   = 0x00001000
+};
+
+/* Remember to fill in descriptions below */
+static struct MethodInfo methods[] = {
+	/* FIXME: we need to alias ssh to sftp */
+	{ "sftp",  SHOW_PORT | SHOW_USER },
+	{ "ftp",  SHOW_PORT | SHOW_USER },
+	{ "ftp",  DEFAULT_METHOD | IS_ANONYMOUS | SHOW_PORT},
+	{ "smb",  SHOW_SHARE | SHOW_USER | SHOW_DOMAIN },
+	{ "dav",  SHOW_PORT | SHOW_USER },
+	/* FIXME: hrm, shouldn't it work? */
+	{ "davs", SHOW_PORT | SHOW_USER },
+	{ NULL,   0 }, /* Custom URI method */
+};
+
+/* To get around non constant gettext strings */
+static const char*
+get_method_description (struct MethodInfo *meth)
+{
+	if (!meth->scheme) {
+		return _("Custom Location");
+	} else if (strcmp (meth->scheme, "sftp") == 0) {
+		return _("SSH");
+	} else if (strcmp (meth->scheme, "ftp") == 0) {
+		if (meth->flags & IS_ANONYMOUS) {
+			return _("Public FTP");
+		} else {
+			return _("FTP (with login)");
+		}
+	} else if (strcmp (meth->scheme, "smb") == 0) {
+		return _("Windows share");
+	} else if (strcmp (meth->scheme, "dav") == 0) {
+		return _("WebDAV (HTTP)");
+	} else if (strcmp (meth->scheme, "davs") == 0) {
+		return _("Secure WebDAV (HTTPS)");
+	
+	/* No descriptive text */
+	} else {
+		return meth->scheme;
+	}
+}
 
 static void
 baobab_remote_connect_dialog_finalize (GObject *object)
@@ -92,60 +208,33 @@ baobab_remote_connect_dialog_finalize (GObject *object)
 	g_object_unref (dialog->details->folder_entry);
 	g_object_unref (dialog->details->domain_entry);
 	g_object_unref (dialog->details->user_entry);
-	g_object_unref (dialog->details->name_entry);
 	
 	g_free (dialog->details);
 
 	G_OBJECT_CLASS (baobab_remote_connect_dialog_parent_class)->finalize (object);
 }
 
-
-static gboolean
-remote_connect (BaobabRemoteConnectDialog *dialog)
+static void
+connect_to_server (BaobabRemoteConnectDialog *dialog, GtkWindow *app)
 {
+	struct MethodInfo *meth;
 	char *uri;
-	char *user_uri;
-	GnomeVFSURI *vfs_uri;
-	char *error_message;
-	char *name;
-	int type;
+	GFile *location;
+	int index;
+	GtkTreeIter iter;
 	
-	type = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->details->type_combo));
+	/* Get our method info */
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->details->type_combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->details->type_combo)),
+			    &iter, 0, &index, -1);
+	g_assert (index < G_N_ELEMENTS (methods) && index >= 0);
+	meth = &(methods[index]);
 
-	if (type == TYPE_URI) {
-		user_uri = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->uri_entry), 0, -1);
-		uri = gnome_vfs_make_uri_from_input (user_uri);
-		g_free (user_uri);
-	
-		vfs_uri = gnome_vfs_uri_new (uri);
-		
-		if (vfs_uri == NULL) {
-			GtkWidget *dlg;
-
-			error_message = g_strdup_printf (_("\"%s\" is not a valid location."), uri);
-			
-			dlg = gtk_message_dialog_new (GTK_WINDOW (dialog),
-						      GTK_DIALOG_DESTROY_WITH_PARENT,
-						      GTK_MESSAGE_ERROR,
-						      GTK_BUTTONS_OK,
-						      error_message);
-
-			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
-					_("Please check the spelling and try again."));
-
-			g_free(error_message);
-
-			gtk_dialog_run (GTK_DIALOG (dlg));
-    			gtk_widget_destroy (dlg);
-
-			return FALSE;
-		}
-		else {
-			gnome_vfs_uri_unref (vfs_uri);
-		}
-	}
-	else {
-		char *method, *user, *port, *initial_path, *server, *folder, *domain;
+	if (meth->scheme == NULL) {
+		uri = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->uri_entry), 0, -1);
+		/* FIXME: we should validate it in some way? */
+	} else {
+		char *user, *port, *initial_path, *server, *folder ,*domain ;
 		char *t, *join;
 		gboolean free_initial_path, free_user, free_domain, free_port;
 
@@ -157,20 +246,18 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_MESSAGE_ERROR,
 						      GTK_BUTTONS_OK,
-						      _("You must enter a name for the server."));
+						      _("Cannot Connect to Server. You must enter a name for the server."));
 
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg),
 					_("Please enter a name and try again."));
 
-			g_free(server);
-
 			gtk_dialog_run (GTK_DIALOG (dlg));
     			gtk_widget_destroy (dlg);
 
-			return FALSE;
+			g_free (server);
+			return;
 		}
 		
-		method = "";
 		user = "";
 		port = "";
 		initial_path = "";
@@ -179,30 +266,17 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 		free_user = FALSE;
 		free_domain = FALSE;
 		free_port = FALSE;
-		switch (type) {
-		case TYPE_SSH:
-			method = "sftp";
-			break;
-		case TYPE_ANON_FTP:
-			method = "ftp";
+		
+		/* FTP special case */
+		if (meth->flags & IS_ANONYMOUS) {
 			user = "anonymous";
-			break;
-		case TYPE_FTP:
-			method = "ftp";
-			break;
-		case TYPE_SMB:
-			method = "smb";
+		
+		/* SMB special case */
+		} else if (strcmp (meth->scheme, "smb") == 0) {
 			t = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->share_entry), 0, -1);
 			initial_path = g_strconcat ("/", t, NULL);
 			free_initial_path = TRUE;
 			g_free (t);
-			break;
-		case TYPE_DAV:
-			method = "dav";
-			break;
-		case TYPE_DAVS:
-			method = "davs";
-			break;
 		}
 
 		if (dialog->details->port_entry->parent != NULL) {
@@ -215,7 +289,7 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 			
 			t = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->user_entry), 0, -1);
 
-			user = gnome_vfs_escape_string (t);
+			user = g_uri_escape_string (t, G_URI_RESERVED_CHARS_ALLOWED_IN_USERINFO, FALSE);
 
 			g_free (t);
 		}
@@ -249,11 +323,11 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 		g_free (t);
 
 		t = folder;
-		folder = gnome_vfs_escape_path_string (t);
+		folder = g_uri_escape_string (t, G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, FALSE);
 		g_free (t);
 
 		uri = g_strdup_printf ("%s://%s%s%s%s%s%s",
-				       method,
+				       meth->scheme,
 				       user, (user[0] != 0) ? "@" : "",
 				       server,
 				       (port[0] != 0) ? ":" : "", port,
@@ -274,61 +348,31 @@ remote_connect (BaobabRemoteConnectDialog *dialog)
 			g_free (domain);
 		}
 	}
-	
-	name = gtk_editable_get_chars (GTK_EDITABLE (dialog->details->name_entry), 0, -1);
-	if (strlen (name) == 0) {
-		const char *host, *path;
-		char *path_utf8, *basename;
-		
-		g_free (name);
-		
-		vfs_uri = gnome_vfs_uri_new (uri);
-	
-		if (vfs_uri == NULL) {
-			g_warning ("Illegal uri in connect to server!\n");
-			g_free (uri);
-			g_free (name);
-			return FALSE;
-		} 
 
-		host = gnome_vfs_uri_get_host_name (vfs_uri);
-		path = gnome_vfs_uri_get_path (vfs_uri);
-		if (path != NULL &&
-		    strlen (path) > 0 &&
-		    strcmp (path, "/") != 0) {
-			path_utf8 = gnome_vfs_format_uri_for_display (uri);
-			basename = g_path_get_basename (path_utf8);
-			name = g_strdup_printf (_("%s on %s"), basename, host);
-			g_free (path_utf8);
-			g_free (basename);
-		} else {
-			name = g_strdup (host);
-		}
-		gnome_vfs_uri_unref (vfs_uri);
-	}
+	gtk_widget_hide (GTK_WIDGET (dialog));
 
-	g_string_assign(baobab.last_scan_command,uri);
-	
+	location = g_file_new_for_uri (uri);
 	g_free (uri);
-	g_free (name);
 
-	return TRUE;
+	connect_server_dialog_present_uri (app,
+					   location,
+					   GTK_WIDGET (dialog));
 }
 
 static void
 response_callback (BaobabRemoteConnectDialog *dialog,
 		   int response_id,
-		   gpointer data)
+		   GtkWindow *app)
 {
+	GError *error;
+
 	switch (response_id) {
 	case RESPONSE_CONNECT:
-		if (!remote_connect (dialog))
-			g_signal_stop_emission_by_name (dialog, "response");
+		connect_to_server (dialog, app);
 		break;
 	case GTK_RESPONSE_NONE:
 	case GTK_RESPONSE_DELETE_EVENT:
 	case GTK_RESPONSE_CANCEL:
-
 		break;
 	default :
 		g_assert_not_reached ();
@@ -340,21 +384,24 @@ baobab_remote_connect_dialog_class_init (BaobabRemoteConnectDialogClass *class)
 {
 	GObjectClass *gobject_class;
 
-
 	gobject_class = G_OBJECT_CLASS (class);
 	gobject_class->finalize = baobab_remote_connect_dialog_finalize;
-	
-	
 }
 
 static void
 setup_for_type (BaobabRemoteConnectDialog *dialog)
 {
-	int type, i;
-	gboolean show_share, show_port, show_user, show_domain;
+	struct MethodInfo *meth;
+	int index, i;
 	GtkWidget *label, *table;
-
-	type = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->details->type_combo));
+	GtkTreeIter iter;
+	
+	/* Get our method info */
+	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->details->type_combo), &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (GTK_COMBO_BOX (dialog->details->type_combo)),
+			    &iter, 0, &index, -1);
+	g_assert (index < G_N_ELEMENTS (methods) && index >= 0);
+	meth = &(methods[index]);
 
 	if (dialog->details->uri_entry->parent != NULL) {
 		gtk_container_remove (GTK_CONTAINER (dialog->details->table),
@@ -384,10 +431,6 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 		gtk_container_remove (GTK_CONTAINER (dialog->details->table),
 				      dialog->details->domain_entry);
 	}
-	if (dialog->details->name_entry->parent != NULL) {
-		gtk_container_remove (GTK_CONTAINER (dialog->details->table),
-				      dialog->details->name_entry);
-	}
 	/* Destroy all labels */
 	gtk_container_foreach (GTK_CONTAINER (dialog->details->table),
 			       (GtkCallback) gtk_widget_destroy, NULL);
@@ -396,7 +439,7 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 	i = 1;
 	table = dialog->details->table;
 	
-	if (type == TYPE_URI) {
+	if (meth->scheme == NULL) {
 		label = gtk_label_new_with_mnemonic (_("_Location (URI):"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_widget_show (label);
@@ -415,35 +458,10 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 				  0, 0);
 
 		i++;
-		
+
 		return;
 	}
 	
-	switch (type) {
-	default:
-	case TYPE_SSH:
-	case TYPE_FTP:
-	case TYPE_DAV:
-	case TYPE_DAVS:
-		show_share = FALSE;
-		show_port = TRUE;
-		show_user = TRUE;
-		show_domain = FALSE;
-		break;
-	case TYPE_ANON_FTP:
-		show_share = FALSE;
-		show_port = TRUE;
-		show_user = FALSE;
-		show_domain = FALSE;
-		break;
-	case TYPE_SMB:
-		show_share = TRUE;
-		show_port = FALSE;
-		show_user = TRUE;
-		show_domain =TRUE;
-		break;
-	}
-
 	label = gtk_label_new_with_mnemonic (_("_Server:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
@@ -474,7 +492,7 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 
 	i++;
 	
-	if (show_share) {
+	if (meth->flags & SHOW_SHARE) {
 		label = gtk_label_new_with_mnemonic (_("_Share:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_widget_show (label);
@@ -495,7 +513,7 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 		i++;
 	}
 
-	if (show_port) {
+	if (meth->flags & SHOW_PORT) {
 		label = gtk_label_new_with_mnemonic (_("_Port:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_widget_show (label);
@@ -535,7 +553,7 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 
 	i++;
 
-	if (show_user) {
+	if (meth->flags & SHOW_USER) {
 		label = gtk_label_new_with_mnemonic (_("_User Name:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_widget_show (label);
@@ -556,7 +574,7 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 		i++;
 	}
 
-	if (show_domain) {
+	if (meth->flags & SHOW_DOMAIN) {
 		label = gtk_label_new_with_mnemonic (_("_Domain Name:"));
 		gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 		gtk_widget_show (label);
@@ -576,8 +594,6 @@ setup_for_type (BaobabRemoteConnectDialog *dialog)
 
                 i++;
         }
-
-	
 }
 
 static void
@@ -587,25 +603,31 @@ combo_changed_callback (GtkComboBox *combo_box,
 	setup_for_type (dialog);
 }
 
-
 static void
 port_insert_text (GtkEditable *editable,
 		  const gchar *new_text,
 		  gint         new_text_length,
 		  gint        *position)
 {
+	int pos;
+
 	if (new_text_length < 0) {
 		new_text_length = strlen (new_text);
 	}
 
-	if (new_text_length != 1 ||
-	    !g_ascii_isdigit (new_text[0])) {
-		gdk_display_beep (gtk_widget_get_display (GTK_WIDGET (editable)));
-		g_signal_stop_emission_by_name (editable, "insert_text");
+	/* Only allow digits to be inserted as port number */
+	for (pos = 0; pos < new_text_length; pos++) {
+		if (!g_ascii_isdigit (new_text[pos])) {
+			GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (editable));
+			if (toplevel != NULL) {
+				gdk_window_beep (toplevel->window);
+			}
+		    g_signal_stop_emission_by_name (editable, "insert_text");
+		    return;
+		}
 	}
 }
 
-
 static void
 baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 {
@@ -614,10 +636,13 @@ baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 	GtkWidget *combo;
 	GtkWidget *hbox;
 	GtkWidget *vbox;
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
+	int i;
 	
 	dialog->details = g_new0 (BaobabRemoteConnectDialogDetails, 1);
 
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Connect to a Remote Folder"));
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Connect to Server"));
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
@@ -640,23 +665,58 @@ baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 	gtk_box_pack_start (GTK_BOX (hbox),
 			    label, FALSE, FALSE, 0);
 
-	dialog->details->type_combo = combo = gtk_combo_box_new_text ();
-	/* Keep this in sync with enum */
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("SSH"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("Public FTP"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("FTP (with login)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("Windows share"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("WebDAV (HTTP)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("Secure WebDAV (HTTPS)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo),
-				   _("Custom Location"));
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), TYPE_ANON_FTP);
+	dialog->details->type_combo = combo = gtk_combo_box_new ();
+
+	/* each row contains: method index, textual description */
+	store = gtk_list_store_new (2, G_TYPE_INT, G_TYPE_STRING);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+	g_object_unref (G_OBJECT (store));
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo), renderer, "text", 1);
+
+	for (i = 0; i < G_N_ELEMENTS (methods); i++) {
+		GtkTreeIter iter;
+		const gchar * const *supported;
+		int j;
+
+		/* skip methods that don't have corresponding GnomeVFSMethods */
+		supported = g_vfs_get_supported_uri_schemes (g_vfs_get_default ());
+
+		if (methods[i].scheme != NULL) {
+			gboolean found;
+
+			found = FALSE;
+			for (j = 0; supported[j] != NULL; j++) {
+				if (strcmp (methods[i].scheme, supported[j]) == 0) {
+					found = TRUE;
+					break;
+				}
+			}
+
+			if (!found) {
+				continue;
+			}
+		}
+
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    0, i,
+				    1, get_method_description (&(methods[i])),
+				    -1);
+
+
+		if (methods[i].flags & DEFAULT_METHOD) {
+			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
+		}
+	}
+
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (combo)) < 0) {
+		/* default method not available, use any other */
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+	}
+
 	gtk_widget_show (combo);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
 	gtk_box_pack_start (GTK_BOX (hbox),
@@ -694,7 +754,15 @@ baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 	dialog->details->folder_entry = gtk_entry_new ();
 	dialog->details->domain_entry = gtk_entry_new ();
 	dialog->details->user_entry = gtk_entry_new ();
-	dialog->details->name_entry = gtk_entry_new ();
+
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->uri_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->server_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->share_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->port_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->folder_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->domain_entry), TRUE);
+	gtk_entry_set_activates_default (GTK_ENTRY (dialog->details->user_entry), TRUE);
+
 	/* We need an extra ref so we can remove them from the table */
 	g_object_ref (dialog->details->uri_entry);
 	g_object_ref (dialog->details->server_entry);
@@ -703,7 +771,6 @@ baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 	g_object_ref (dialog->details->folder_entry);
 	g_object_ref (dialog->details->domain_entry);
 	g_object_ref (dialog->details->user_entry);
-	g_object_ref (dialog->details->name_entry);
 	
 	setup_for_type (dialog);
 	
@@ -711,48 +778,28 @@ baobab_remote_connect_dialog_init (BaobabRemoteConnectDialog *dialog)
 			       GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("C_onnect"),
+			       _("_Scan"),
 			       RESPONSE_CONNECT);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 					 RESPONSE_CONNECT);
-
-	g_signal_connect (dialog, "response",
-			  G_CALLBACK (response_callback),
-			  dialog);
-
-
 }
 
 GtkWidget *
-baobab_remote_connect_dialog_new (GtkWindow *window, const gchar *location)
+baobab_remote_connect_dialog_new (GtkWindow *window, GFile *location)
 {
-	BaobabRemoteConnectDialog *conndlg;
 	GtkWidget *dialog;
-	GnomeVFSURI *uri;
 
 	dialog = gtk_widget_new (BAOBAB_TYPE_REMOTE_CONNECT_DIALOG, NULL);
 
-	if (window) {
-		conndlg = BAOBAB_REMOTE_CONNECT_DIALOG(dialog);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (response_callback),
+			  window);
 
+	if (window) {
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				       gtk_window_get_screen (GTK_WINDOW (window)));
-
-		if (location) {
-			uri = gnome_vfs_uri_new (location);
-			g_return_val_if_fail (uri != NULL, dialog);
-
-			/* ... and if it's a remote URI, then load as the default */
-			if (!g_str_equal (gnome_vfs_uri_get_scheme (uri), "file") && 
-			    !gnome_vfs_uri_is_local (uri)) {
-
-				gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->details->type_combo), TYPE_URI);
-				gtk_entry_set_text (GTK_ENTRY (conndlg->details->uri_entry), location);
-			}
-;
-			gnome_vfs_uri_unref (uri);
-		}
 	}
 
 	return dialog;
 }
+
