@@ -82,7 +82,7 @@ static void findbar_close_cb  (LogviewFindbar *findbar,
 static void read_new_lines_cb (LogviewLog *log,
                                const char **lines,
                                GSList *new_days,
-                               GError **error,
+                               GError *error,
                                gpointer user_data);
 
 /* private functions */
@@ -242,7 +242,7 @@ logview_set_font (LogviewWindow *logview,
 }
 
 static void
-logview_set_fontsize (LogviewWindow *logview)
+logview_set_fontsize (LogviewWindow *logview, gboolean store)
 {
   PangoFontDescription *fontdesc;
   PangoContext *context;
@@ -253,7 +253,9 @@ logview_set_fontsize (LogviewWindow *logview)
   pango_font_description_set_size (fontdesc, (priv->fontsize) * PANGO_SCALE);
   gtk_widget_modify_font (priv->text_view, fontdesc);
 
-  logview_prefs_store_fontsize (logview->priv->prefs, priv->fontsize);
+  if (store) {
+    logview_prefs_store_fontsize (logview->priv->prefs, priv->fontsize);
+  }
 }
 
 static void
@@ -386,21 +388,21 @@ static void
 logview_bigger_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MIN (logview->priv->fontsize + 1, 24);
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }	
 
 static void
 logview_smaller_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = MAX (logview->priv->fontsize-1, 6);
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }	
 
 static void
 logview_normal_text (GtkAction *action, LogviewWindow *logview)
 {
   logview->priv->fontsize = logview->priv->original_fontsize;
-  logview_set_fontsize (logview);
+  logview_set_fontsize (logview, TRUE);
 }
 
 static void
@@ -996,7 +998,7 @@ static void
 read_new_lines_cb (LogviewLog *log,
                    const char **lines,
                    GSList *new_days,
-                   GError **error,
+                   GError *error,
                    gpointer user_data)
 {
   LogviewWindow *window = user_data;
@@ -1005,9 +1007,23 @@ read_new_lines_cb (LogviewLog *log,
   int i, old_line_count, filter_start_line;
   GtkTextIter iter, start;
   GtkTextMark *mark;
-  char *converted;
+  char *converted, *primary;
   gsize len;
 
+  if (error != NULL) {
+    primary = g_strdup_printf (_("Can't read from \"%s\""),
+                               logview_log_get_display_name (log));
+    logview_window_add_error (window, primary, error->message);
+    g_free (primary);
+
+    return;
+  }
+
+  if (lines == NULL) {
+    /* there's no error, but no lines have been read */
+    return;
+  }
+
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (window->priv->text_view));
   old_line_count = gtk_text_buffer_get_line_count (buffer);
   filter_start_line = old_line_count > 0 ? (old_line_count - 1) : 0;
@@ -1403,7 +1419,13 @@ logview_window_init (LogviewWindow *logview)
 
   /* restore saved zoom */
   priv->fontsize = logview_prefs_get_stored_fontsize (priv->prefs);
-  logview_set_fontsize (logview);
+
+  if (priv->fontsize <= 0) {
+    /* restore the default */
+    logview_normal_text (NULL, logview);
+  } else {
+    logview_set_fontsize (logview, FALSE);
+  }
 
   /* version selector */
   priv->version_bar = gtk_hbox_new (FALSE, 0);
